Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(181)

Unified Diff: net/http/http_server_properties.h

Issue 9802003: SPDY - persist SPDY settings. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_server_properties.h
===================================================================
--- net/http/http_server_properties.h (revision 127896)
+++ net/http/http_server_properties.h (working copy)
@@ -37,7 +37,7 @@
};
typedef std::map<HostPortPair, PortAlternateProtocolPair> AlternateProtocolMap;
-typedef std::map<HostPortPair, spdy::SpdySettings> SpdySettingsMap;
+typedef std::map<HostPortPair, spdy::SettingsMap> SpdySettingsMap;
typedef std::map<HostPortPair,
HttpPipelinedHostCapability> PipelineCapabilityMap;
@@ -84,26 +84,22 @@
// Returns all Alternate-Protocol mappings.
virtual const AlternateProtocolMap& alternate_protocol_map() const = 0;
- // Gets a reference to the SpdySettings stored for a host.
- // If no settings are stored, returns an empty set of settings.
- virtual const spdy::SpdySettings& GetSpdySettings(
+ // Gets a reference to the SettingsMap stored for a host.
+ // If no settings are stored, returns an empty SettingsMap.
+ virtual const spdy::SettingsMap& GetSpdySettings(
const HostPortPair& host_port_pair) const = 0;
- // Saves settings for a host. Returns true if SpdySettings are to be
- // persisted. Used by unittests only.
- // TODO(rtenneti): Move this method to test utility file.
- virtual bool SetSpdySettings(const HostPortPair& host_port_pair,
- const spdy::SpdySettings& settings) = 0;
+ // Saves an individual SPDY setting for a host. Returns true if SPDY setting
+ // is to be persisted.
+ virtual bool SetSpdySetting(
+ const HostPortPair& host_port_pair,
+ uint32 id,
+ const spdy::SettingsFlagsAndValue& flags_and_value) = 0;
Ryan Hamilton 2012/03/21 16:24:41 Please expand this out to take flags and value ind
ramant (doing other things) 2012/03/23 04:11:25 Done.
- // Saves an individual setting for a host. Returns true if SpdySetting is to
- // be persisted.
- virtual bool SetSpdySetting(const HostPortPair& host_port_pair,
- const spdy::SpdySetting& setting) = 0;
-
- // Clears all spdy_settings.
+ // Clears all SPDY settings.
virtual void ClearSpdySettings() = 0;
- // Returns all persistent SpdySettings.
+ // Returns all SPDY settings.
virtual const SpdySettingsMap& spdy_settings_map() const = 0;
virtual HttpPipelinedHostCapability GetPipelineCapability(

Powered by Google App Engine
This is Rietveld 408576698